@@ -346,6 +346,7 @@ sample_group_sim_from_ontology <- function(
 #' @param min_terms Minimum number of times a term should occur within the given group to be eligible for inclusion in the results.
 #' @return \code{data.frame} containing columns: \code{term} (with the term ID); \code{name} (term readable name); \code{in_term} (number of sets in the given group of containing the term); \code{in_no_term} (number of sets in the given group not containing the term); \code{out_term} and \code{out_no_term} (equivalently for the sets not in the given group); \code{p} (the p-values calculated by permutation for seeing a term with such a strong association, measured using Fisher's exact test, in a group of term sets the size of the given group among \code{term_sets}). Rows ordered by significance (i.e. the \code{p} columns).
 #' @param mc.cores If not null and greater than on, the number of cores use calculating permutations (passed to \code{mclapply}).
+#' @param ... Arguments to pass to \code{fisher.test}.
 #' @export
 #' @seealso \code{\link{sample_group_sim}} \code{\link{create_sim_index}}
 #' @importFrom parallel mclapply
@@ -358,7 +359,8 @@ group_term_enrichment <- function(
 	group,
 	permutations=1000L,
 	min_terms=2L,
-	mc.cores=NULL
+	mc.cores=NULL,
+	...
 ) {
 	if (is.character(group) & !is.null(names(term_sets))) group <- names(term_sets) %in% group
 	if (is.integer(group)) group <- seq_along(term_sets) %in% group
@@ -376,7 +378,7 @@ group_term_enrichment <- function(
 			term=tf
 		)))
 		ft <- table(f)
-		ps <- apply(term_tab, 2, function(x) fisher.test(rbind(x, ft-x))$p.value)
+		ps <- apply(term_tab, 2, function(x) fisher.test(rbind(x, ft-x), ...)$p.value)
 		if (just_p) min(ps) else list(ft=ft, p=ps, terms=term_tab)
 	}
 	r <- fn(group)
