@@ -9,7 +9,7 @@ double multiply(double a, double b) { return a * b; }
 double a(double a, double b) { return a; }
 double worst(double a, double b) { return min(a, b); }
 double by_size(double total, int n) { return total / (double)n; }
-double identity(double a, int b) { return a; }
+double identity_fun(double a, int b) { return a; }
 
 GroupSim::~GroupSim() {}
 SimMatrix::~SimMatrix() {}
